.. _getting_started:


###############
Getting started
###############

.. _installing-ttcrpy:

*****************
Installing ttcrpy
*****************

You can use pip to install the package by doing::

  pip install ttcrpy

Requirements
============

ttcrpy needs the following packages:
  - numpy (https://numpy.org)
  - scipy (https://www.scipy.org)
  - vtk (https://www.vtk.org)

***************
Simple examples
***************

An example showing how easy it is to use the code can be found at
https://github.com/groupeLIAMG/ttcr/blob/master/examples/example_Grid3d.ipynb

A second example illustrating how to run jobs in parallel is given at
https://github.com/groupeLIAMG/ttcr/blob/master/examples/example_tmesh_parallel.ipynb
